From: David Marchand <david.marchand@redhat.com>
To: dev@dpdk.org
Cc: Tyler Retzlaff <roretzla@linux.microsoft.com>,
Bruce Richardson <bruce.richardson@intel.com>,
Dmitry Kozlyuk <dmitry.kozliuk@gmail.com>
Subject: [PATCH v31 03/12] eal: introduce log options parser
Date: Thu, 7 Nov 2024 21:51:35 +0100 [thread overview]
Message-ID: <20241107205145.2424871-4-david.marchand@redhat.com> (raw)
In-Reply-To: <20241107205145.2424871-1-david.marchand@redhat.com>
Rename existing log level option parser and add a little helper tracking
all options related to logs.
This will make it easier to add more log options in the next commits.
Signed-off-by: David Marchand <david.marchand@redhat.com>
---
lib/eal/common/eal_common_options.c | 26 ++++++++++++++++++--------
lib/eal/common/eal_options.h | 3 ++-
lib/eal/freebsd/eal.c | 8 ++++----
lib/eal/linux/eal.c | 8 ++++----
lib/eal/windows/eal.c | 7 ++++---
5 files changed, 32 insertions(+), 20 deletions(-)
diff --git a/lib/eal/common/eal_common_options.c b/lib/eal/common/eal_common_options.c
index 17c378f0c7..ab6cf8bebf 100644
--- a/lib/eal/common/eal_common_options.c
+++ b/lib/eal/common/eal_common_options.c
@@ -1640,9 +1640,20 @@ eal_parse_huge_unlink(const char *arg, struct hugepage_file_discipline *out)
return -1;
}
-/* Parse the arguments for --log-level only */
+bool
+eal_option_is_log(int opt)
+{
+ switch (opt) {
+ case OPT_LOG_LEVEL_NUM:
+ return true;
+ default:
+ return false;
+ }
+}
+
+/* Parse all arguments looking for log related ones */
int
-eal_log_level_parse(int argc, char * const argv[])
+eal_parse_log_options(int argc, char * const argv[])
{
struct internal_config *internal_conf = eal_get_internal_configuration();
int option_index, opt;
@@ -1661,12 +1672,11 @@ eal_log_level_parse(int argc, char * const argv[])
while ((opt = getopt_long(argc, argv, eal_short_options,
eal_long_options, &option_index)) != EOF) {
- switch (opt) {
- case OPT_LOG_LEVEL_NUM:
- if (eal_parse_common_option(opt, optarg, internal_conf) < 0)
- return -1;
- break;
- }
+ if (!eal_option_is_log(opt))
+ continue;
+
+ if (eal_parse_common_option(opt, optarg, internal_conf) < 0)
+ return -1;
}
/* restore getopt lib */
diff --git a/lib/eal/common/eal_options.h b/lib/eal/common/eal_options.h
index f3f2e104f6..06ba023c5a 100644
--- a/lib/eal/common/eal_options.h
+++ b/lib/eal/common/eal_options.h
@@ -96,7 +96,8 @@ enum {
extern const char eal_short_options[];
extern const struct option eal_long_options[];
-int eal_log_level_parse(int argc, char * const argv[]);
+bool eal_option_is_log(int opt);
+int eal_parse_log_options(int argc, char * const argv[]);
int eal_parse_common_option(int opt, const char *argv,
struct internal_config *conf);
int eal_option_device_parse(void);
diff --git a/lib/eal/freebsd/eal.c b/lib/eal/freebsd/eal.c
index d3b40e81d8..8563ef1156 100644
--- a/lib/eal/freebsd/eal.c
+++ b/lib/eal/freebsd/eal.c
@@ -392,8 +392,8 @@ eal_parse_args(int argc, char **argv)
goto out;
}
- /* eal_log_level_parse() already handled this option */
- if (opt == OPT_LOG_LEVEL_NUM)
+ /* eal_parse_log_options() already handled this option */
+ if (eal_option_is_log(opt))
continue;
ret = eal_parse_common_option(opt, optarg, internal_conf);
@@ -574,8 +574,8 @@ rte_eal_init(int argc, char **argv)
/* clone argv to report out later in telemetry */
eal_save_args(argc, argv);
- /* set log level as early as possible */
- eal_log_level_parse(argc, argv);
+ /* parse log options as early as possible */
+ eal_parse_log_options(argc, argv);
if (rte_eal_cpu_init() < 0) {
rte_eal_init_alert("Cannot detect lcores.");
diff --git a/lib/eal/linux/eal.c b/lib/eal/linux/eal.c
index 40d750ed0d..9ac52ea500 100644
--- a/lib/eal/linux/eal.c
+++ b/lib/eal/linux/eal.c
@@ -610,8 +610,8 @@ eal_parse_args(int argc, char **argv)
goto out;
}
- /* eal_log_level_parse() already handled this option */
- if (opt == OPT_LOG_LEVEL_NUM)
+ /* eal_parse_log_options() already handled this option */
+ if (eal_option_is_log(opt))
continue;
ret = eal_parse_common_option(opt, optarg, internal_conf);
@@ -950,8 +950,8 @@ rte_eal_init(int argc, char **argv)
eal_reset_internal_config(internal_conf);
- /* set log level as early as possible */
- eal_log_level_parse(argc, argv);
+ /* parse log options as early as possible */
+ eal_parse_log_options(argc, argv);
/* clone argv to report out later in telemetry */
eal_save_args(argc, argv);
diff --git a/lib/eal/windows/eal.c b/lib/eal/windows/eal.c
index a77e590a72..69d367fb8e 100644
--- a/lib/eal/windows/eal.c
+++ b/lib/eal/windows/eal.c
@@ -120,8 +120,8 @@ eal_parse_args(int argc, char **argv)
return -1;
}
- /* eal_log_level_parse() already handled this option */
- if (opt == OPT_LOG_LEVEL_NUM)
+ /* eal_parse_log_options() already handled this option */
+ if (eal_option_is_log(opt))
continue;
ret = eal_parse_common_option(opt, optarg, internal_conf);
@@ -252,7 +252,8 @@ rte_eal_init(int argc, char **argv)
eal_log_init(NULL, 0);
- eal_log_level_parse(argc, argv);
+ /* parse log options as early as possible */
+ eal_parse_log_options(argc, argv);
if (eal_create_cpu_map() < 0) {
rte_eal_init_alert("Cannot discover CPU and NUMA.");
--
2.47.0
next prev parent reply other threads:[~2024-11-07 20:52 UTC|newest]
Thread overview: 486+ messages / expand[flat|nested] mbox.gz Atom feed top
2020-08-14 17:34 [dpdk-dev] [PATCH] eal: add option to put timestamp on console output Stephen Hemminger
2020-08-14 18:39 ` Dmitry Kozlyuk
2020-08-14 18:45 ` Stephen Hemminger
2020-08-14 19:09 ` Dmitry Kozlyuk
2020-08-14 19:20 ` Stephen Hemminger
2020-08-17 10:37 ` Bruce Richardson
2020-08-17 15:11 ` Stephen Hemminger
2020-10-19 14:11 ` Thomas Monjalon
2020-10-19 15:25 ` Stephen Hemminger
2024-03-21 17:22 ` Thomas Monjalon
2023-03-06 18:18 ` [PATCH v2 0/2] Add option to timestamp console log Stephen Hemminger
2023-03-06 18:18 ` [PATCH v2 1/2] eal: unify logging code for FreeBsd and Linux Stephen Hemminger
2023-03-06 18:18 ` [PATCH v2 2/2] eal: add option to put timestamp on console output Stephen Hemminger
2023-03-07 9:09 ` [PATCH v2 0/2] Add option to timestamp console log Bruce Richardson
2023-03-06 19:28 ` [PATCH v3 " Stephen Hemminger
2023-03-06 19:28 ` [PATCH v3 1/2] eal: unify logging code for FreeBsd and Linux Stephen Hemminger
2023-03-06 19:28 ` [PATCH v3 2/2] eal: add option to put timestamp on console output Stephen Hemminger
2023-03-07 9:35 ` fengchengwen
2023-03-07 16:05 ` Stephen Hemminger
2023-03-07 16:06 ` Stephen Hemminger
2023-03-08 0:36 ` fengchengwen
2023-03-08 2:03 ` Stephen Hemminger
2023-03-09 0:55 ` fengchengwen
2023-03-08 2:51 ` Stephen Hemminger
2023-03-07 7:33 ` [PATCH v3 0/2] Add option to timestamp console log Morten Brørup
2023-03-07 9:12 ` Bruce Richardson
2023-03-07 16:04 ` Stephen Hemminger
2023-06-26 18:42 ` [PATCH v4 0/5] Logging related patchs Stephen Hemminger
2023-06-26 18:42 ` [PATCH v4 1/5] eal: unify logging code for FreeBsd and Linux Stephen Hemminger
2023-06-26 18:42 ` [PATCH v4 2/5] eal: turn off getopt_long error message during eal_log_level Stephen Hemminger
2023-06-26 18:42 ` [PATCH v4 3/5] eal: skip stdio on console logging Stephen Hemminger
2023-06-26 18:42 ` [PATCH v4 4/5] eal: move logging initialization earlier Stephen Hemminger
2023-06-26 18:42 ` [PATCH v4 5/5] eal: add option to put timestamp on console output Stephen Hemminger
2023-06-27 7:40 ` [PATCH v4 0/5] Logging related patchs Morten Brørup
2023-06-27 14:49 ` Stephen Hemminger
2023-06-27 15:04 ` Morten Brørup
2023-06-27 15:02 ` Bruce Richardson
2023-06-28 17:58 ` [PATCH v5 0/6] Logging related patches Stephen Hemminger
2023-06-28 17:58 ` [PATCH v5 1/6] eal: unify logging code for FreeBsd and Linux Stephen Hemminger
2023-06-28 17:58 ` [PATCH v5 2/6] eal: turn off getopt_long error message during eal_log_level Stephen Hemminger
2023-06-28 17:58 ` [PATCH v5 3/6] eal: fix handling of syslog facility Stephen Hemminger
2023-06-28 17:58 ` [PATCH v5 4/6] eal: skip stdio on console logging Stephen Hemminger
2023-06-28 17:58 ` [PATCH v5 5/6] eal: allow user to set default log stream before init Stephen Hemminger
2023-06-28 17:58 ` [PATCH v5 6/6] eal: add option to put timestamp on console output Stephen Hemminger
2023-06-29 15:58 ` [PATCH v6 0/6] Logging related patches Stephen Hemminger
2023-06-29 15:58 ` [PATCH v6 1/6] eal: unify logging code Stephen Hemminger
2023-06-29 15:58 ` [PATCH v6 2/6] eal: turn off getopt_long error message during eal_log_level Stephen Hemminger
2023-06-29 15:58 ` [PATCH v6 3/6] eal: fix help message for syslog option Stephen Hemminger
2023-06-29 15:58 ` [PATCH v6 4/6] eal: skip stdio on console logging Stephen Hemminger
2023-06-29 15:58 ` [PATCH v6 5/6] eal: allow user to set default log stream before init Stephen Hemminger
2023-06-29 15:58 ` [PATCH v6 6/6] eal: add option to put timestamp on console output Stephen Hemminger
2023-07-05 22:48 ` [PATCH v7 0/5] Logging timetamp and related patches Stephen Hemminger
2023-07-05 22:48 ` [PATCH v7 1/5] windows: make getopt functions have const properties Stephen Hemminger
2023-07-10 21:10 ` Tyler Retzlaff
2023-07-05 22:48 ` [PATCH v7 2/5] eal: fix help message for syslog option Stephen Hemminger
2023-07-05 22:48 ` [PATCH v7 3/5] eal: unify logging code Stephen Hemminger
2023-07-05 22:48 ` [PATCH v7 4/5] eal: allow user to set default log stream before init Stephen Hemminger
2023-07-05 22:48 ` [PATCH v7 5/5] eal: add option to put timestamp on console output Stephen Hemminger
2024-03-18 18:30 ` [PATCH v8 0/5] Logging timestamp and related patches Stephen Hemminger
2024-03-18 18:30 ` [PATCH v8 1/5] log: unify logging code Stephen Hemminger
2024-03-18 18:30 ` [PATCH v8 2/5] eal: make eal_log_level_parse common Stephen Hemminger
2024-03-18 18:30 ` [PATCH v8 3/5] eal: allow user to set default log stream before init Stephen Hemminger
2024-03-18 18:30 ` [PATCH v8 4/5] eal: add option to put timestamp on console output Stephen Hemminger
2024-03-18 18:30 ` [PATCH v8 5/5] eal: initialize logging before plugins Stephen Hemminger
2024-03-18 22:02 ` [PATCH v9 0/5] Logging unification and timestamp Stephen Hemminger
2024-03-18 22:02 ` [PATCH v9 1/5] log: unify logging code Stephen Hemminger
2024-03-18 22:02 ` [PATCH v9 2/5] eal: make eal_log_level_parse common Stephen Hemminger
2024-03-18 22:02 ` [PATCH v9 3/5] eal: initialize logging before plugins Stephen Hemminger
2024-03-18 22:03 ` [PATCH v9 4/5] eal: allow user to set default log stream before init Stephen Hemminger
2024-03-18 22:03 ` [PATCH v9 5/5] eal: add option to put timestamp on console output Stephen Hemminger
2024-03-19 7:37 ` Morten Brørup
2024-03-19 15:51 ` Stephen Hemminger
2024-03-19 16:13 ` Morten Brørup
2024-03-20 3:33 ` Stephen Hemminger
2024-03-20 8:34 ` Morten Brørup
2024-03-20 14:38 ` Stephen Hemminger
2024-03-20 17:38 ` Morten Brørup
2024-03-21 16:00 ` [PATCH v10 00/10] Logging enhancements Stephen Hemminger
2024-03-21 16:00 ` [PATCH v10 01/10] windows: make getopt functions have const properties Stephen Hemminger
2024-03-21 16:00 ` [PATCH v10 02/10] log: unify logging code Stephen Hemminger
2024-03-21 16:00 ` [PATCH v10 03/10] eal: make eal_log_level_parse common Stephen Hemminger
2024-03-21 17:00 ` Tyler Retzlaff
2024-03-21 16:00 ` [PATCH v10 04/10] eal: initialize log earlier in startup Stephen Hemminger
2024-03-21 16:00 ` [PATCH v10 05/10] eal: do not duplicate rte_init_alert() messages Stephen Hemminger
2024-03-21 16:00 ` [PATCH v10 06/10] eal: change rte_exit() output to match rte_log() Stephen Hemminger
2024-03-21 17:04 ` Tyler Retzlaff
2024-03-21 16:00 ` [PATCH v10 07/10] eal: allow user to set default log stream before init Stephen Hemminger
2024-03-21 17:07 ` Tyler Retzlaff
2024-03-21 16:00 ` [PATCH v10 08/10] eal: add option to put timestamp on console output Stephen Hemminger
2024-03-21 17:11 ` Tyler Retzlaff
2024-03-21 17:16 ` Stephen Hemminger
2024-03-21 17:49 ` Tyler Retzlaff
2024-03-22 0:30 ` Stephen Hemminger
2024-03-21 16:00 ` [PATCH v10 09/10] log: colorize log output Stephen Hemminger
2024-03-21 16:00 ` [PATCH v10 10/10] doc: add documentation of logging options Stephen Hemminger
2024-03-24 2:33 ` [PATCH v11 0/9] Logging unification and enhancements Stephen Hemminger
2024-03-24 2:33 ` [PATCH v11 1/9] windows: make getopt functions have const properties Stephen Hemminger
2024-03-24 2:33 ` [PATCH v11 2/9] eal: make eal_log_level_parse common Stephen Hemminger
2024-03-24 2:33 ` [PATCH v11 3/9] eal: do not duplicate rte_init_alert() messages Stephen Hemminger
2024-03-24 2:33 ` [PATCH v11 4/9] eal: change rte_exit() output to match rte_log() Stephen Hemminger
2024-03-24 2:33 ` [PATCH v11 5/9] log: drop syslog support, and make code common Stephen Hemminger
2024-03-24 2:33 ` [PATCH v11 6/9] log: add hook for printing log messages Stephen Hemminger
2024-03-24 2:33 ` [PATCH v11 7/9] log: add timestamp option Stephen Hemminger
2024-03-24 2:33 ` [PATCH v11 8/9] log: add support for systemd journal Stephen Hemminger
2024-03-24 2:33 ` [PATCH v11 9/9] log: colorize log output Stephen Hemminger
2024-03-24 11:18 ` [PATCH v11 0/9] Logging unification and enhancements Mattias Rönnblom
2024-03-25 20:46 ` [PATCH v12 00/14] " Stephen Hemminger
2024-03-25 20:46 ` [PATCH v12 01/14] windows: make getopt functions have const properties Stephen Hemminger
2024-03-25 20:46 ` [PATCH v12 02/14] windows: add os shim for localtime_r Stephen Hemminger
2024-03-25 20:47 ` [PATCH v12 03/14] eal: make eal_log_level_parse common Stephen Hemminger
2024-03-25 20:47 ` [PATCH v12 04/14] eal: do not duplicate rte_init_alert() messages Stephen Hemminger
2024-03-25 20:47 ` [PATCH v12 05/14] eal: change rte_exit() output to match rte_log() Stephen Hemminger
2024-03-27 7:17 ` Tyler Retzlaff
2024-03-25 20:47 ` [PATCH v12 06/14] log: move handling of syslog facility out of eal Stephen Hemminger
2024-03-25 20:47 ` [PATCH v12 07/14] eal: initialize log before everything else Stephen Hemminger
2024-03-25 20:47 ` [PATCH v12 08/14] log: drop syslog support, and make code common Stephen Hemminger
2024-03-25 20:47 ` [PATCH v12 09/14] log: add hook for printing log messages Stephen Hemminger
2024-03-25 20:47 ` [PATCH v12 10/14] log: add timestamp option Stephen Hemminger
2024-03-25 20:47 ` [PATCH v12 11/14] log: add optional support of syslog Stephen Hemminger
2024-03-25 20:47 ` [PATCH v12 12/14] log: add support for systemd journal Stephen Hemminger
2024-03-25 20:47 ` [PATCH v12 13/14] log: colorize log output Stephen Hemminger
2024-03-25 20:47 ` [PATCH v12 14/14] maintainers: add for log library Stephen Hemminger
2024-03-26 1:56 ` [PATCH v13 00/11] Logging unification and improvements Stephen Hemminger
2024-03-26 1:56 ` [PATCH v13 01/11] windows: make getopt functions have const properties Stephen Hemminger
2024-03-26 9:35 ` Morten Brørup
2024-03-26 1:56 ` [PATCH v13 02/11] windows: add os shim for localtime_r Stephen Hemminger
2024-03-26 1:56 ` [PATCH v13 03/11] eal: make eal_log_level_parse common Stephen Hemminger
2024-03-26 1:56 ` [PATCH v13 04/11] eal: do not duplicate rte_init_alert() messages Stephen Hemminger
2024-03-26 1:57 ` [PATCH v13 05/11] eal: change rte_exit() output to match rte_log() Stephen Hemminger
2024-03-26 1:57 ` [PATCH v13 06/11] log: move handling of syslog facility out of eal Stephen Hemminger
2024-03-26 1:57 ` [PATCH v13 07/11] eal: initialize log before everything else Stephen Hemminger
2024-03-26 1:57 ` [PATCH v13 08/11] log: drop syslog support, and make code common Stephen Hemminger
2024-03-26 1:57 ` [PATCH v13 09/11] log: add hook for printing log messages Stephen Hemminger
2024-03-26 1:57 ` [PATCH v13 10/11] log: add timestamp option Stephen Hemminger
2024-03-26 1:57 ` [PATCH v13 11/11] log: add optional support of syslog Stephen Hemminger
2024-03-26 17:34 ` [PATCH v14 00/15] Logging unification and improvments Stephen Hemminger
2024-03-26 17:34 ` [PATCH v14 01/15] maintainers: add for log library Stephen Hemminger
2024-03-26 17:34 ` [PATCH v14 02/15] windows: make getopt functions have const properties Stephen Hemminger
2024-03-26 17:34 ` [PATCH v14 03/15] windows: add os shim for localtime_r Stephen Hemminger
2024-03-26 17:34 ` [PATCH v14 04/15] windows: common wrapper for vasprintf and asprintf Stephen Hemminger
2024-03-26 17:34 ` [PATCH v14 05/15] eal: make eal_log_level_parse common Stephen Hemminger
2024-03-26 17:34 ` [PATCH v14 06/15] eal: do not duplicate rte_init_alert() messages Stephen Hemminger
2024-03-26 17:34 ` [PATCH v14 07/15] eal: change rte_exit() output to match rte_log() Stephen Hemminger
2024-03-26 17:34 ` [PATCH v14 08/15] log: move handling of syslog facility out of eal Stephen Hemminger
2024-03-26 17:34 ` [PATCH v14 09/15] eal: initialize log before everything else Stephen Hemminger
2024-03-26 17:34 ` [PATCH v14 10/15] log: drop syslog support, and make code common Stephen Hemminger
2024-03-26 17:34 ` [PATCH v14 11/15] log: add hook for printing log messages Stephen Hemminger
2024-03-26 17:34 ` [PATCH v14 12/15] log: add timestamp option Stephen Hemminger
2024-03-26 17:34 ` [PATCH v14 13/15] log: add optional support of syslog Stephen Hemminger
2024-03-26 17:34 ` [PATCH v14 14/15] log: add support for systemd journal Stephen Hemminger
2024-03-26 17:34 ` [PATCH v14 15/15] log: colorize log output Stephen Hemminger
2024-03-27 0:26 ` [PATCH v15 00/15] Logging unification and improvements Stephen Hemminger
2024-03-27 0:27 ` [PATCH v15 01/15] maintainers: add for log library Stephen Hemminger
2024-03-27 0:27 ` [PATCH v15 02/15] windows: make getopt functions have const properties Stephen Hemminger
2024-03-27 0:27 ` [PATCH v15 03/15] windows: add os shim for localtime_r Stephen Hemminger
2024-03-27 0:27 ` [PATCH v15 04/15] windows: common wrapper for vasprintf and asprintf Stephen Hemminger
2024-03-27 0:27 ` [PATCH v15 05/15] eal: make eal_log_level_parse common Stephen Hemminger
2024-03-27 0:27 ` [PATCH v15 06/15] eal: do not duplicate rte_init_alert() messages Stephen Hemminger
2024-03-27 0:27 ` [PATCH v15 07/15] eal: change rte_exit() output to match rte_log() Stephen Hemminger
2024-03-27 0:27 ` [PATCH v15 08/15] log: move handling of syslog facility out of eal Stephen Hemminger
2024-03-27 0:27 ` [PATCH v15 09/15] eal: initialize log before everything else Stephen Hemminger
2024-03-27 0:27 ` [PATCH v15 10/15] log: drop syslog support, and make code common Stephen Hemminger
2024-03-27 0:27 ` [PATCH v15 11/15] log: add hook for printing log messages Stephen Hemminger
2024-03-27 0:27 ` [PATCH v15 12/15] log: add timestamp option Stephen Hemminger
2024-03-27 0:27 ` [PATCH v15 13/15] log: add optional support of syslog Stephen Hemminger
2024-03-27 0:27 ` [PATCH v15 14/15] log: add support for systemd journal Stephen Hemminger
2024-03-27 0:27 ` [PATCH v15 15/15] log: colorize log output Stephen Hemminger
2024-03-27 16:45 ` [PATCH v16 00/15] Logging unification and improvements Stephen Hemminger
2024-03-27 16:45 ` [PATCH v16 01/15] maintainers: add for log library Stephen Hemminger
2024-03-27 16:52 ` Tyler Retzlaff
2024-03-27 16:45 ` [PATCH v16 02/15] windows: make getopt functions have const properties Stephen Hemminger
2024-03-27 16:45 ` [PATCH v16 03/15] windows: add os shim for localtime_r Stephen Hemminger
2024-03-27 16:56 ` Tyler Retzlaff
2024-03-27 17:30 ` Stephen Hemminger
2024-03-27 16:45 ` [PATCH v16 04/15] windows: common wrapper for vasprintf and asprintf Stephen Hemminger
2024-03-27 17:08 ` Tyler Retzlaff
2024-03-27 16:45 ` [PATCH v16 05/15] eal: make eal_log_level_parse common Stephen Hemminger
2024-03-27 17:11 ` Tyler Retzlaff
2024-03-27 16:45 ` [PATCH v16 06/15] eal: do not duplicate rte_init_alert() messages Stephen Hemminger
2024-03-27 17:11 ` Tyler Retzlaff
2024-03-27 16:45 ` [PATCH v16 07/15] eal: change rte_exit() output to match rte_log() Stephen Hemminger
2024-03-27 17:12 ` Tyler Retzlaff
2024-03-27 16:45 ` [PATCH v16 08/15] log: move handling of syslog facility out of eal Stephen Hemminger
2024-03-27 16:45 ` [PATCH v16 09/15] eal: initialize log before everything else Stephen Hemminger
2024-03-27 17:14 ` Tyler Retzlaff
2024-03-27 16:45 ` [PATCH v16 10/15] log: drop syslog support, and make code common Stephen Hemminger
2024-03-27 16:45 ` [PATCH v16 11/15] log: add hook for printing log messages Stephen Hemminger
2024-03-27 16:45 ` [PATCH v16 12/15] log: add timestamp option Stephen Hemminger
2024-03-27 16:45 ` [PATCH v16 13/15] log: add optional support of syslog Stephen Hemminger
2024-03-27 16:45 ` [PATCH v16 14/15] log: add support for systemd journal Stephen Hemminger
2024-03-27 16:45 ` [PATCH v16 15/15] log: colorize log output Stephen Hemminger
2024-03-27 23:28 ` [PATCH v17 00/15] Logging unification and improvements Stephen Hemminger
2024-03-27 23:28 ` [PATCH v17 01/15] maintainers: add for log library Stephen Hemminger
2024-03-27 23:28 ` [PATCH v17 02/15] windows: make getopt functions have const properties Stephen Hemminger
2024-03-27 23:28 ` [PATCH v17 03/15] windows: add os shim for localtime_r Stephen Hemminger
2024-03-27 23:28 ` [PATCH v17 04/15] windows: common wrapper for vasprintf and asprintf Stephen Hemminger
2024-03-27 23:28 ` [PATCH v17 05/15] eal: make eal_log_level_parse common Stephen Hemminger
2024-03-27 23:28 ` [PATCH v17 06/15] eal: do not duplicate rte_init_alert() messages Stephen Hemminger
2024-03-27 23:28 ` [PATCH v17 07/15] eal: change rte_exit() output to match rte_log() Stephen Hemminger
2024-03-27 23:28 ` [PATCH v17 08/15] log: move handling of syslog facility out of eal Stephen Hemminger
2024-03-27 23:28 ` [PATCH v17 09/15] eal: initialize log before everything else Stephen Hemminger
2024-03-27 23:28 ` [PATCH v17 10/15] log: drop syslog support, and make code common Stephen Hemminger
2024-03-27 23:28 ` [PATCH v17 11/15] log: add hook for printing log messages Stephen Hemminger
2024-03-27 23:28 ` [PATCH v17 12/15] log: add timestamp option Stephen Hemminger
2024-03-27 23:28 ` [PATCH v17 13/15] log: add optional support of syslog Stephen Hemminger
2024-03-27 23:28 ` [PATCH v17 14/15] log: add support for systemd journal Stephen Hemminger
2024-03-27 23:28 ` [PATCH v17 15/15] log: colorize log output Stephen Hemminger
2024-03-28 23:49 ` [PATCH v18 00/15] Logging unification and improvements Stephen Hemminger
2024-03-28 23:49 ` [PATCH v18 01/15] maintainers: add for log library Stephen Hemminger
2024-03-28 23:49 ` [PATCH v18 02/15] windows: make getopt functions have const properties Stephen Hemminger
2024-03-28 23:49 ` [PATCH v18 03/15] windows: add os shim for localtime_r Stephen Hemminger
2024-03-28 23:49 ` [PATCH v18 04/15] windows: common wrapper for vasprintf and asprintf Stephen Hemminger
2024-03-28 23:49 ` [PATCH v18 05/15] eal: make eal_log_level_parse common Stephen Hemminger
2024-03-28 23:49 ` [PATCH v18 06/15] eal: do not duplicate rte_init_alert() messages Stephen Hemminger
2024-03-28 23:49 ` [PATCH v18 07/15] eal: change rte_exit() output to match rte_log() Stephen Hemminger
2024-03-28 23:49 ` [PATCH v18 08/15] log: move handling of syslog facility out of eal Stephen Hemminger
2024-03-28 23:49 ` [PATCH v18 09/15] eal: initialize log before everything else Stephen Hemminger
2024-03-28 23:49 ` [PATCH v18 10/15] log: drop syslog support, and make code common Stephen Hemminger
2024-03-28 23:49 ` [PATCH v18 11/15] log: add hook for printing log messages Stephen Hemminger
2024-03-28 23:49 ` [PATCH v18 12/15] log: add timestamp option Stephen Hemminger
2024-03-28 23:49 ` [PATCH v18 13/15] log: add optional support of syslog Stephen Hemminger
2024-03-28 23:49 ` [PATCH v18 14/15] log: add support for systemd journal Stephen Hemminger
2024-03-28 23:49 ` [PATCH v18 15/15] log: colorize log output Stephen Hemminger
2024-03-30 3:00 ` [PATCH v19 00/15] Logging unification and improvements Stephen Hemminger
2024-03-30 3:00 ` [PATCH v19 01/15] maintainers: add for log library Stephen Hemminger
2024-03-30 3:00 ` [PATCH v19 02/15] windows: make getopt functions have const properties Stephen Hemminger
2024-03-30 3:00 ` [PATCH v19 03/15] windows: add os shim for localtime_r Stephen Hemminger
2024-03-30 3:00 ` [PATCH v19 04/15] windows: common wrapper for vasprintf and asprintf Stephen Hemminger
2024-03-30 3:00 ` [PATCH v19 05/15] eal: make eal_log_level_parse common Stephen Hemminger
2024-03-30 3:00 ` [PATCH v19 06/15] eal: do not duplicate rte_init_alert() messages Stephen Hemminger
2024-03-30 3:00 ` [PATCH v19 07/15] eal: change rte_exit() output to match rte_log() Stephen Hemminger
2024-03-30 3:00 ` [PATCH v19 08/15] log: move handling of syslog facility out of eal Stephen Hemminger
2024-03-30 3:00 ` [PATCH v19 09/15] eal: initialize log before everything else Stephen Hemminger
2024-03-30 3:00 ` [PATCH v19 10/15] log: drop syslog support, and make code common Stephen Hemminger
2024-03-30 3:00 ` [PATCH v19 11/15] log: add hook for printing log messages Stephen Hemminger
2024-03-30 3:00 ` [PATCH v19 12/15] log: add timestamp option Stephen Hemminger
2024-03-30 3:00 ` [PATCH v19 13/15] log: add optional support of syslog Stephen Hemminger
2024-03-30 3:00 ` [PATCH v19 14/15] log: add support for systemd journal Stephen Hemminger
2024-03-30 3:00 ` [PATCH v19 15/15] log: colorize log output Stephen Hemminger
2024-03-30 16:42 ` [PATCH v20 00/14] Logging unification and improvements Stephen Hemminger
2024-03-30 16:42 ` [PATCH v20 01/14] maintainers: add for log library Stephen Hemminger
2024-03-30 16:42 ` [PATCH v20 02/14] windows: make getopt functions have const properties Stephen Hemminger
2024-03-30 16:42 ` [PATCH v20 03/14] windows: add os shim for localtime_r Stephen Hemminger
2024-03-30 16:42 ` [PATCH v20 04/14] eal: make eal_log_level_parse common Stephen Hemminger
2024-03-30 16:42 ` [PATCH v20 05/14] eal: do not duplicate rte_init_alert() messages Stephen Hemminger
2024-03-30 16:42 ` [PATCH v20 06/14] eal: change rte_exit() output to match rte_log() Stephen Hemminger
2024-03-30 16:42 ` [PATCH v20 07/14] log: move handling of syslog facility out of eal Stephen Hemminger
2024-03-30 16:42 ` [PATCH v20 08/14] eal: initialize log before everything else Stephen Hemminger
2024-03-30 16:42 ` [PATCH v20 09/14] log: drop syslog support, and make code common Stephen Hemminger
2024-03-30 16:42 ` [PATCH v20 10/14] log: add hook for printing log messages Stephen Hemminger
2024-03-30 16:42 ` [PATCH v20 11/14] log: add timestamp option Stephen Hemminger
2024-03-30 16:42 ` [PATCH v20 12/14] log: add optional support of syslog Stephen Hemminger
2024-03-30 16:42 ` [PATCH v20 13/14] log: add support for systemd journal Stephen Hemminger
2024-04-01 11:18 ` Luca Boccassi
2024-03-30 16:42 ` [PATCH v20 14/14] log: colorize log output Stephen Hemminger
2024-06-04 0:44 ` [PATCH v21 00/14] Log library unification ane enhancements Stephen Hemminger
2024-06-04 0:44 ` [PATCH v21 01/14] maintainers: add for log library Stephen Hemminger
2024-06-06 5:35 ` Morten Brørup
2024-06-04 0:44 ` [PATCH v21 02/14] windows: make getopt functions have const properties Stephen Hemminger
2024-06-04 2:31 ` Stephen Hemminger
2024-06-04 0:44 ` [PATCH v21 03/14] windows: add os shim for localtime_r Stephen Hemminger
2024-06-04 0:44 ` [PATCH v21 04/14] eal: make eal_log_level_parse common Stephen Hemminger
2024-06-04 0:44 ` [PATCH v21 05/14] eal: do not duplicate rte_init_alert() messages Stephen Hemminger
2024-06-04 0:44 ` [PATCH v21 06/14] eal: change rte_exit() output to match rte_log() Stephen Hemminger
2024-06-04 0:44 ` [PATCH v21 07/14] log: move handling of syslog facility out of eal Stephen Hemminger
2024-06-04 0:44 ` [PATCH v21 08/14] eal: initialize log before everything else Stephen Hemminger
2024-06-04 0:44 ` [PATCH v21 09/14] log: drop syslog support, and make code common Stephen Hemminger
2024-06-04 2:30 ` Stephen Hemminger
2024-06-04 0:44 ` [PATCH v21 10/14] log: add hook for printing log messages Stephen Hemminger
2024-06-04 0:44 ` [PATCH v21 11/14] log: add timestamp option Stephen Hemminger
2024-06-04 2:33 ` Stephen Hemminger
2024-06-04 0:45 ` [PATCH v21 12/14] log: add optional support of syslog Stephen Hemminger
2024-06-04 2:34 ` Stephen Hemminger
2024-06-04 0:45 ` [PATCH v21 13/14] log: add support for systemd journal Stephen Hemminger
2024-06-04 2:35 ` Stephen Hemminger
2024-06-04 0:45 ` [PATCH v21 14/14] log: colorize log output Stephen Hemminger
2024-06-04 2:37 ` Stephen Hemminger
2024-09-17 20:35 ` [PATCH v22 00/15] Logging improvements Stephen Hemminger
2024-09-17 20:35 ` [PATCH v22 01/15] maintainers: add for log library Stephen Hemminger
2024-09-17 20:35 ` [PATCH v22 02/15] windows: make getopt functions have const properties Stephen Hemminger
2024-09-17 20:35 ` [PATCH v22 03/15] windows: add os shim for localtime_r Stephen Hemminger
2024-09-17 20:35 ` [PATCH v22 04/15] eal: make eal_log_level_parse common Stephen Hemminger
2024-09-17 20:35 ` [PATCH v22 05/15] eal: do not duplicate rte_init_alert() messages Stephen Hemminger
2024-09-17 20:35 ` [PATCH v22 06/15] eal: change rte_exit() output to match rte_log() Stephen Hemminger
2024-09-17 20:35 ` [PATCH v22 07/15] log: move handling of syslog facility out of eal Stephen Hemminger
2024-09-17 20:35 ` [PATCH v22 08/15] eal: initialize log before everything else Stephen Hemminger
2024-09-17 20:35 ` [PATCH v22 09/15] log: drop syslog support, and make code common Stephen Hemminger
2024-09-17 20:35 ` [PATCH v22 10/15] log: add hook for printing log messages Stephen Hemminger
2024-09-17 20:35 ` [PATCH v22 11/15] log: add timestamp option Stephen Hemminger
2024-09-17 20:35 ` [PATCH v22 12/15] log: add optional support of syslog Stephen Hemminger
2024-09-17 20:35 ` [PATCH v22 13/15] log: add support for systemd journal Stephen Hemminger
2024-09-17 20:35 ` [PATCH v22 14/15] log: colorize log output Stephen Hemminger
2024-09-17 20:35 ` [PATCH v22 15/15] doc: add release note about log library Stephen Hemminger
2024-09-18 4:38 ` Morten Brørup
2024-09-18 4:56 ` [PATCH v23 00/15] Logging improvements Stephen Hemminger
2024-09-18 4:56 ` [PATCH v23 01/15] maintainers: add for log library Stephen Hemminger
2024-09-18 7:01 ` fengchengwen
2024-09-18 4:56 ` [PATCH v23 02/15] windows: make getopt functions have const properties Stephen Hemminger
2024-09-18 7:04 ` fengchengwen
2024-09-18 4:56 ` [PATCH v23 03/15] windows: add os shim for localtime_r Stephen Hemminger
2024-09-18 7:09 ` fengchengwen
2024-09-18 15:25 ` Stephen Hemminger
2024-09-18 4:56 ` [PATCH v23 04/15] eal: make eal_log_level_parse common Stephen Hemminger
2024-09-18 7:18 ` fengchengwen
2024-09-18 15:24 ` Stephen Hemminger
2024-09-18 4:56 ` [PATCH v23 05/15] eal: do not duplicate rte_init_alert() messages Stephen Hemminger
2024-09-18 7:18 ` fengchengwen
2024-09-18 4:56 ` [PATCH v23 06/15] eal: change rte_exit() output to match rte_log() Stephen Hemminger
2024-09-18 7:23 ` fengchengwen
2024-09-18 4:56 ` [PATCH v23 07/15] log: move handling of syslog facility out of eal Stephen Hemminger
2024-09-18 7:25 ` fengchengwen
2024-09-18 4:56 ` [PATCH v23 08/15] eal: initialize log before everything else Stephen Hemminger
2024-09-18 7:30 ` fengchengwen
2024-09-18 4:56 ` [PATCH v23 09/15] log: drop syslog support, and make code common Stephen Hemminger
2024-09-18 4:56 ` [PATCH v23 10/15] log: add hook for printing log messages Stephen Hemminger
2024-09-18 7:32 ` fengchengwen
2024-09-18 4:56 ` [PATCH v23 11/15] log: add timestamp option Stephen Hemminger
2024-09-18 7:37 ` fengchengwen
2024-09-18 15:05 ` Stephen Hemminger
2024-09-19 1:20 ` fengchengwen
2024-09-18 4:56 ` [PATCH v23 12/15] log: add optional support of syslog Stephen Hemminger
2024-09-18 7:41 ` fengchengwen
2024-09-18 4:56 ` [PATCH v23 13/15] log: add support for systemd journal Stephen Hemminger
2024-09-18 4:56 ` [PATCH v23 14/15] log: colorize log output Stephen Hemminger
2024-09-18 7:43 ` fengchengwen
2024-09-18 4:56 ` [PATCH v23 15/15] doc: add release note about log library Stephen Hemminger
2024-09-18 7:44 ` fengchengwen
2024-09-18 8:27 ` [PATCH v23 00/15] Logging improvements Bruce Richardson
2024-09-18 20:51 ` [PATCH v24 00/15] Logging enhancements for 24.11 Stephen Hemminger
2024-09-18 20:52 ` [PATCH v24 01/15] maintainers: add for log library Stephen Hemminger
2024-09-18 20:52 ` [PATCH v24 02/15] windows: make getopt functions have const properties Stephen Hemminger
2024-09-18 20:52 ` [PATCH v24 03/15] windows: add os shim for localtime_r Stephen Hemminger
2024-09-19 1:07 ` fengchengwen
2024-09-18 20:52 ` [PATCH v24 04/15] eal: make eal_log_level_parse common Stephen Hemminger
2024-09-18 20:52 ` [PATCH v24 05/15] eal: do not duplicate rte_init_alert() messages Stephen Hemminger
2024-09-18 20:52 ` [PATCH v24 06/15] eal: change rte_exit() output to match rte_log() Stephen Hemminger
2024-09-19 1:09 ` fengchengwen
2024-09-18 20:52 ` [PATCH v24 07/15] log: move handling of syslog facility out of eal Stephen Hemminger
2024-09-18 20:52 ` [PATCH v24 08/15] eal: initialize log before everything else Stephen Hemminger
2024-09-18 20:52 ` [PATCH v24 09/15] log: drop syslog support, and make code common Stephen Hemminger
2024-09-18 20:52 ` [PATCH v24 10/15] log: add hook for printing log messages Stephen Hemminger
2024-09-18 20:52 ` [PATCH v24 11/15] log: add timestamp option Stephen Hemminger
2024-09-18 20:52 ` [PATCH v24 12/15] log: add optional support of syslog Stephen Hemminger
2024-09-18 20:52 ` [PATCH v24 13/15] log: add support for systemd journal Stephen Hemminger
2024-09-18 20:52 ` [PATCH v24 14/15] log: colorize log output Stephen Hemminger
2024-09-18 20:52 ` [PATCH v24 15/15] doc: add release note about log library Stephen Hemminger
2024-09-19 15:04 ` [PATCH v25 00/15] Logging enhancements for 24.11 Stephen Hemminger
2024-09-19 15:04 ` [PATCH v25 01/15] maintainers: add for log library Stephen Hemminger
2024-09-19 15:04 ` [PATCH v25 02/15] windows: make getopt functions have const properties Stephen Hemminger
2024-09-19 15:04 ` [PATCH v25 03/15] windows: add os shim for localtime_r Stephen Hemminger
2024-09-19 15:04 ` [PATCH v25 04/15] eal: make eal_log_level_parse common Stephen Hemminger
2024-09-19 15:04 ` [PATCH v25 05/15] eal: do not duplicate rte_init_alert() messages Stephen Hemminger
2024-09-19 15:04 ` [PATCH v25 06/15] eal: change rte_exit() output to match rte_log() Stephen Hemminger
2024-09-19 15:04 ` [PATCH v25 07/15] log: move handling of syslog facility out of eal Stephen Hemminger
2024-09-19 15:04 ` [PATCH v25 08/15] eal: initialize log before everything else Stephen Hemminger
2024-09-19 15:04 ` [PATCH v25 09/15] log: drop syslog support, and make code common Stephen Hemminger
2024-09-19 15:04 ` [PATCH v25 10/15] log: add hook for printing log messages Stephen Hemminger
2024-09-19 15:04 ` [PATCH v25 11/15] log: add timestamp option Stephen Hemminger
2024-09-19 15:04 ` [PATCH v25 12/15] log: add optional support of syslog Stephen Hemminger
2024-09-19 15:04 ` [PATCH v25 13/15] log: add support for systemd journal Stephen Hemminger
2024-09-19 15:04 ` [PATCH v25 14/15] log: colorize log output Stephen Hemminger
2024-09-19 15:04 ` [PATCH v25 15/15] doc: add release note about log library Stephen Hemminger
2024-09-30 20:34 ` Tyler Retzlaff
2024-09-20 14:47 ` [PATCH v25 00/15] Logging enhancements for 24.11 Patrick Robb
2024-10-16 20:20 ` [PATCH v26 00/15] Log subsystem improvements Stephen Hemminger
2024-10-16 20:20 ` [PATCH v26 01/15] maintainers: add for log library Stephen Hemminger
2024-10-16 20:20 ` [PATCH v26 02/15] windows: make getopt functions have const properties Stephen Hemminger
2024-10-16 20:20 ` [PATCH v26 03/15] windows: add os shim for localtime_r Stephen Hemminger
2024-10-16 20:20 ` [PATCH v26 04/15] eal: make eal_log_level_parse common Stephen Hemminger
2024-10-16 20:20 ` [PATCH v26 05/15] eal: do not duplicate rte_init_alert() messages Stephen Hemminger
2024-10-17 16:47 ` David Marchand
2024-10-17 17:17 ` Stephen Hemminger
2024-10-16 20:20 ` [PATCH v26 06/15] eal: change rte_exit() output to match rte_log() Stephen Hemminger
2024-10-16 20:20 ` [PATCH v26 07/15] log: move handling of syslog facility out of eal Stephen Hemminger
2024-10-16 20:20 ` [PATCH v26 08/15] eal: initialize log before everything else Stephen Hemminger
2024-10-16 20:20 ` [PATCH v26 09/15] log: drop syslog support, and make code common Stephen Hemminger
2024-10-16 20:20 ` [PATCH v26 10/15] log: add hook for printing log messages Stephen Hemminger
2024-10-16 20:20 ` [PATCH v26 11/15] log: add timestamp option Stephen Hemminger
2024-10-16 20:20 ` [PATCH v26 12/15] log: add optional support of syslog Stephen Hemminger
2024-10-16 20:20 ` [PATCH v26 13/15] log: add support for systemd journal Stephen Hemminger
2024-10-16 20:20 ` [PATCH v26 14/15] log: colorize log output Stephen Hemminger
2024-10-16 20:20 ` [PATCH v26 15/15] doc: add release note about log library Stephen Hemminger
2024-10-18 17:07 ` [PATCH v26 00/15] Log subsystem improvements David Marchand
2024-10-18 17:45 ` Stephen Hemminger
2024-10-20 7:16 ` Baruch Even
2024-10-24 3:18 ` [PATCH v27 00/14] Log subsystem changes Stephen Hemminger
2024-10-24 3:18 ` [PATCH v27 01/14] maintainers: add for log library Stephen Hemminger
2024-10-24 3:18 ` [PATCH v27 02/14] windows: make getopt functions have const properties Stephen Hemminger
2024-10-24 3:18 ` [PATCH v27 03/14] windows: update os shim Stephen Hemminger
2024-10-24 3:18 ` [PATCH v27 04/14] eal: make eal_log_level_parse common Stephen Hemminger
2024-10-24 3:18 ` [PATCH v27 05/14] eal: do not duplicate rte_init_alert() messages Stephen Hemminger
2024-10-24 3:18 ` [PATCH v27 06/14] eal: change rte_exit() output to match rte_log() Stephen Hemminger
2024-10-24 3:18 ` [PATCH v27 07/14] log: move handling of syslog facility out of eal Stephen Hemminger
2024-10-24 3:18 ` [PATCH v27 08/14] eal: initialize log before everything else Stephen Hemminger
2024-10-24 3:18 ` [PATCH v27 09/14] log: add hook for printing log messages Stephen Hemminger
2024-10-24 3:18 ` [PATCH v27 10/14] log: modify syslog handling Stephen Hemminger
2024-10-24 3:18 ` [PATCH v27 11/14] log: add timestamp option Stephen Hemminger
2024-10-24 3:18 ` [PATCH v27 12/14] log: add support for systemd journal Stephen Hemminger
2024-10-24 3:18 ` [PATCH v27 13/14] log: colorize log output Stephen Hemminger
2024-10-25 15:49 ` Baruch Even
2024-10-24 3:18 ` [PATCH v27 14/14] doc: add release note about log library Stephen Hemminger
2024-10-24 19:02 ` [PATCH v28 00/13] Logging subsystem improvements Stephen Hemminger
2024-10-24 19:02 ` [PATCH v28 01/13] maintainers: add for log library Stephen Hemminger
2024-10-24 19:02 ` [PATCH v28 02/13] windows: make getopt functions have const properties Stephen Hemminger
2024-10-24 19:02 ` [PATCH v28 03/13] windows: update os shim Stephen Hemminger
2024-10-24 19:02 ` [PATCH v28 04/13] eal: make eal_log_level_parse common Stephen Hemminger
2024-10-24 19:02 ` [PATCH v28 05/13] eal: do not duplicate rte_init_alert() messages Stephen Hemminger
2024-10-24 19:02 ` [PATCH v28 06/13] eal: change rte_exit() output to match rte_log() Stephen Hemminger
2024-10-24 19:02 ` [PATCH v28 07/13] log: rework syslog handling Stephen Hemminger
2024-10-24 19:02 ` [PATCH v28 08/13] eal: initialize log before everything else Stephen Hemminger
2024-10-24 19:02 ` [PATCH v28 09/13] log: add hook for printing log messages Stephen Hemminger
2024-10-24 19:02 ` [PATCH v28 10/13] log: add timestamp option Stephen Hemminger
2024-10-24 19:02 ` [PATCH v28 11/13] log: add support for systemd journal Stephen Hemminger
2024-10-25 15:33 ` Baruch Even
2024-10-25 15:56 ` Stephen Hemminger
2024-10-24 19:02 ` [PATCH v28 12/13] log: colorize log output Stephen Hemminger
2024-10-24 19:02 ` [PATCH v28 13/13] doc: add release note about log library Stephen Hemminger
2024-10-25 21:45 ` [PATCH v29 00/13] Logging subsystem enhancements Stephen Hemminger
2024-10-25 21:45 ` [PATCH v29 01/13] maintainers: add for log library Stephen Hemminger
2024-10-25 21:45 ` [PATCH v29 02/13] windows: make getopt functions have const properties Stephen Hemminger
2024-10-25 21:45 ` [PATCH v29 03/13] windows: update os shim Stephen Hemminger
2024-10-25 21:45 ` [PATCH v29 04/13] eal: make eal_log_level_parse common Stephen Hemminger
2024-10-25 21:45 ` [PATCH v29 05/13] eal: do not duplicate rte_init_alert() messages Stephen Hemminger
2024-10-25 21:45 ` [PATCH v29 06/13] eal: change rte_exit() output to match rte_log() Stephen Hemminger
2024-10-25 21:45 ` [PATCH v29 07/13] log: rework syslog handling Stephen Hemminger
2024-10-25 21:45 ` [PATCH v29 08/13] eal: initialize log before everything else Stephen Hemminger
2024-10-25 21:45 ` [PATCH v29 09/13] log: add hook for printing log messages Stephen Hemminger
2024-10-25 21:45 ` [PATCH v29 10/13] log: add timestamp option Stephen Hemminger
2024-10-25 21:45 ` [PATCH v29 11/13] log: add support for systemd journal Stephen Hemminger
2024-10-25 21:45 ` [PATCH v29 12/13] log: colorize log output Stephen Hemminger
2024-10-25 21:45 ` [PATCH v29 13/13] doc: add release note about log library Stephen Hemminger
2024-10-27 17:24 ` [PATCH v30 00/13] Log library enhancements Stephen Hemminger
2024-10-27 17:24 ` [PATCH v30 01/13] maintainers: add for log library Stephen Hemminger
2024-10-27 17:24 ` [PATCH v30 02/13] windows: make getopt functions have const properties Stephen Hemminger
2024-10-27 17:24 ` [PATCH v30 03/13] windows: update os shim Stephen Hemminger
2024-10-27 17:24 ` [PATCH v30 04/13] eal: make eal_log_level_parse common Stephen Hemminger
2024-10-27 17:24 ` [PATCH v30 05/13] eal: do not duplicate rte_init_alert() messages Stephen Hemminger
2024-10-27 17:24 ` [PATCH v30 06/13] eal: change rte_exit() output to match rte_log() Stephen Hemminger
2024-10-27 17:24 ` [PATCH v30 07/13] log: rework syslog handling Stephen Hemminger
2024-10-27 17:24 ` [PATCH v30 08/13] eal: initialize log before everything else Stephen Hemminger
2024-10-27 17:24 ` [PATCH v30 09/13] log: add hook for printing log messages Stephen Hemminger
2024-10-27 17:24 ` [PATCH v30 10/13] log: add timestamp option Stephen Hemminger
2024-10-27 17:24 ` [PATCH v30 11/13] log: add support for systemd journal Stephen Hemminger
2024-10-27 17:24 ` [PATCH v30 12/13] log: colorize log output Stephen Hemminger
2024-10-27 17:24 ` [PATCH v30 13/13] doc: add release note about log library Stephen Hemminger
2024-11-07 20:51 ` [PATCH v31 00/12] Log library enhancements David Marchand
2024-11-07 20:51 ` [PATCH v31 01/12] eal/windows: align getopt to FreeBSD David Marchand
2024-11-07 20:51 ` [PATCH v31 02/12] eal: factorize parser for log level David Marchand
2024-11-07 20:51 ` David Marchand [this message]
2024-11-07 20:51 ` [PATCH v31 04/12] eal: do not log init failure twice David Marchand
2024-11-07 20:51 ` [PATCH v31 05/12] eal: improve exit output log David Marchand
2024-11-07 20:51 ` [PATCH v31 06/12] log: rework syslog handling David Marchand
2024-11-07 20:51 ` [PATCH v31 07/12] eal: initialize log before everything else David Marchand
2024-11-07 20:51 ` [PATCH v31 08/12] log: add hook for printing log messages David Marchand
2024-11-07 20:51 ` [PATCH v31 09/12] log: add timestamp option David Marchand
2024-11-07 20:51 ` [PATCH v31 10/12] log: support systemd journal David Marchand
2024-11-07 20:51 ` [PATCH v31 11/12] log: colorize log output David Marchand
2024-11-07 20:51 ` [PATCH v31 12/12] maintainers: update for log library David Marchand
2024-11-08 8:51 ` [PATCH v31 00/12] Log library enhancements David Marchand
2024-11-08 8:47 ` David Marchand
2024-11-08 8:47 ` [PATCH v32 01/12] eal/windows: align getopt to FreeBSD David Marchand
2024-11-08 8:47 ` [PATCH v32 02/12] eal: factorize parser for log level David Marchand
2024-11-08 8:47 ` [PATCH v32 03/12] eal: introduce log options parser David Marchand
2024-11-08 8:47 ` [PATCH v32 04/12] eal: do not log init failure twice David Marchand
2024-11-08 8:47 ` [PATCH v32 05/12] eal: improve exit output log David Marchand
2024-11-08 8:47 ` [PATCH v32 06/12] log: rework syslog handling David Marchand
2024-11-08 8:47 ` [PATCH v32 07/12] eal: initialize log before everything else David Marchand
2024-11-08 8:47 ` [PATCH v32 08/12] log: add hook for printing log messages David Marchand
2024-11-08 8:47 ` [PATCH v32 09/12] log: add timestamp option David Marchand
2024-11-08 8:47 ` [PATCH v32 10/12] log: support systemd journal David Marchand
2024-11-08 8:48 ` [PATCH v32 11/12] log: colorize log output David Marchand
2024-11-08 8:48 ` [PATCH v32 12/12] maintainers: update for log library David Marchand
2024-11-08 8:56 ` [PATCH v32 00/12] Log library enhancements David Marchand
2024-11-08 8:56 ` [PATCH v32 01/12] eal/windows: align getopt to FreeBSD David Marchand
2024-11-08 8:56 ` [PATCH v32 02/12] eal: factorize parser for log level David Marchand
2024-11-08 8:57 ` [PATCH v32 03/12] eal: introduce log options parser David Marchand
2024-11-08 8:57 ` [PATCH v32 04/12] eal: do not log init failure twice David Marchand
2024-11-08 8:57 ` [PATCH v32 05/12] eal: improve exit output log David Marchand
2024-11-08 8:57 ` [PATCH v32 06/12] log: rework syslog handling David Marchand
2024-11-08 8:57 ` [PATCH v32 07/12] eal: initialize log before everything else David Marchand
2024-11-08 8:57 ` [PATCH v32 08/12] log: add hook for printing log messages David Marchand
2024-11-08 8:57 ` [PATCH v32 09/12] log: add timestamp option David Marchand
2024-11-08 8:57 ` [PATCH v32 10/12] log: support systemd journal David Marchand
2024-11-08 8:57 ` [PATCH v32 11/12] log: colorize log output David Marchand
2024-11-08 8:57 ` [PATCH v32 12/12] maintainers: update for log library David Marchand
2024-11-08 17:08 ` [PATCH v32 00/12] Log library enhancements David Marchand
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=20241107205145.2424871-4-david.marchand@redhat.com \
--to=david.marchand@redhat.com \
--cc=bruce.richardson@intel.com \
--cc=dev@dpdk.org \
--cc=dmitry.kozliuk@gmail.com \
--cc=roretzla@linux.microsoft.com \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for NNTP newsgroup(s).